@@ -51,16 +51,17 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   GtkWidget *list_item;
   GtkWidget *button;       
   GtkWidget *padding;       
-  GtkWidget *vbox2;       
+  GtkWidget *vbox2;
+  GtkWidget *swin;
   GtkStyle *style;
   GtkBox *vbox;
   char buffer[10];
-  char *title[] = {"Action database"};
+  const gchar *title[] = {"Action database"};
   int i;
   
   /* Create main window ------------------------------------------------  */
   actions_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_container_border_width (GTK_CONTAINER (actions_dialog), 5);
+  gtk_container_set_border_width (GTK_CONTAINER (actions_dialog), 5);
   gtk_window_set_title (GTK_WINDOW (actions_dialog), "Monitor options");
   gtk_widget_set_style (actions_dialog, cfg->main_style);
   gtk_widget_set_usize (actions_dialog, 400, -1);
@@ -72,13 +73,15 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
 		      NULL);
   
   vbox = (GtkBox *)gtk_vbox_new (FALSE, 2);
-  gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
   gtk_container_add (GTK_CONTAINER (actions_dialog), GTK_WIDGET (vbox));
   gtk_widget_show (GTK_WIDGET (vbox)); 
   
   /* List with actions */
 
   ctree = GTK_CTREE (gtk_ctree_new_with_titles (1, 0, title));
+  swin = gtk_scrolled_window_new (NULL, NULL);
+  gtk_container_add (GTK_CONTAINER (swin), GTK_WIDGET (ctree));
   gtk_ctree_set_line_style (ctree, GTK_CTREE_LINES_DOTTED);
   gtk_ctree_set_reorderable (ctree, TRUE);
   gtk_widget_set_usize (GTK_WIDGET (ctree), -1, 300);
@@ -96,14 +99,14 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   GTK_SIGNAL_FUNC (after_move), NULL);
   -------------------------------------------------------------------- */
 
-  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (ctree), TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (swin), TRUE, TRUE, 0);
   gtk_clist_column_titles_passive (GTK_CLIST (ctree));
   gtk_clist_set_column_justification (GTK_CLIST (ctree), 1, GTK_JUSTIFY_RIGHT);
   gtk_clist_set_selection_mode (GTK_CLIST (ctree), GTK_SELECTION_SINGLE);
-  gtk_clist_set_policy (GTK_CLIST (ctree), GTK_POLICY_ALWAYS,
-			GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
+				  GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);
   gtk_clist_set_column_width (GTK_CLIST (ctree), 0, 300);
-  gtk_widget_show (GTK_WIDGET(ctree));
+  gtk_widget_show_all (GTK_WIDGET(swin));
       
       
   /* Make bottom part ------------------------------------------------ */
@@ -534,7 +537,7 @@ edit_action_entry (Action *action)
   
   /* Create main window ------------------------------------------------  */
   action_record = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_container_border_width (GTK_CONTAINER (action_record), 5);
+  gtk_container_set_border_width (GTK_CONTAINER (action_record), 5);
   gtk_window_set_title (GTK_WINDOW (action_record), "Edit action record");
   gtk_widget_set_style (action_record, cfg->main_style);
   gtk_widget_set_usize (action_record, 400, 400);
@@ -546,7 +549,7 @@ edit_action_entry (Action *action)
 		      action_record);
   
   vbox = (GtkBox *)gtk_vbox_new (FALSE, 2);
-  gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
   gtk_container_add (GTK_CONTAINER (action_record), GTK_WIDGET (vbox));
   gtk_widget_show (GTK_WIDGET (vbox)); 
   
