@@ -129,7 +129,7 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
    if (CalendarDialog == NULL)
    {
       CalendarDialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-      gtk_container_border_width (GTK_CONTAINER (CalendarDialog), 1);
+      gtk_container_set_border_width (GTK_CONTAINER (CalendarDialog), 1);
       gtk_window_set_title (GTK_WINDOW (CalendarDialog), "Calendar");
       gtk_signal_connect (GTK_OBJECT (CalendarDialog), "destroy",
 			  GTK_SIGNAL_FUNC (CloseCalendar),
@@ -140,7 +140,7 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
 
       gtk_widget_set_style (CalendarDialog, cfg->main_style);
       vbox = gtk_vbox_new (FALSE, 2);
-      gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+      gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
       gtk_container_add (GTK_CONTAINER (CalendarDialog), vbox);
       gtk_widget_show (vbox);
 
@@ -175,7 +175,7 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
 
       frame = gtk_frame_new (NULL);
       gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-      gtk_container_border_width (GTK_CONTAINER (frame), 3);
+      gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
       gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
       gtk_widget_set_style (frame, cfg->main_style);
       gtk_widget_show (frame);
