@@ -475,7 +475,7 @@ UpdateStatusArea ()
       strncpy (status_text, curlog->name, 30);
       gtk_label_get ( filename_label, (char **)&buffer);
       if (strcmp (status_text, buffer) != 0)
-	gtk_label_set (filename_label, status_text);
+	gtk_label_set_text (filename_label, status_text);
     }
 
   tdm = &curlog->curmark->fulldate;
@@ -483,7 +483,7 @@ UpdateStatusArea ()
 	   tdm->tm_mday, tdm->tm_mon, tdm->tm_year);
   gtk_label_get ( date_label, (char **)&buffer);
   if (strcmp (status_text, buffer) != 0)
-    gtk_label_set (date_label, status_text);
+    gtk_label_set_text (date_label, status_text);
 
   return;
 }
