@@ -681,7 +681,12 @@ ReadLogStats (Log * log)
       if (IsLeapYear (curmark->year - lastyear + thisyear))
 	 curmark->time += 24 * 60 * 60;		/*  Add one day */
 
+#ifdef __NetBSD__
+      curmark->time += correction - tmptm->tm_gmtoff;
+#else
       curmark->time += correction - timezone;
+#endif
+
       memcpy (&curmark->fulldate, localtime (&curmark->time), sizeof (struct tm));
 
 /*       fprintf (stderr, "%s\n", ctime (&curmark->time)); */
@@ -702,14 +707,22 @@ ReadLogStats (Log * log)
    if (IsLeapYear (thisyear))
       log->lstats.enddate += 24 * 60 * 60;	/*  Add one day */
 
+#ifdef __NetBSD__
+   log->lstats.enddate += correction - tmptm->tm_gmtoff;
+#else
    log->lstats.enddate += correction - timezone;
+#endif
 
    footm.tm_year = thisyear - lastyear;
    correction = mktime (&footm);
    if (IsLeapYear (thisyear - lastyear))
       log->lstats.startdate += 24 * 60 * 60;	/*  Add one day */
 
+#ifdef __NetBSD__
+   log->lstats.startdate += correction - tmptm->tm_gmtoff;
+#else
    log->lstats.startdate += correction - timezone;
+#endif
    log->lstats.numlines = nl;
 
    return;
