@@ -187,7 +187,7 @@ int
 main (int argc, char *argv[])
 {
   /*  Initialize gnome & gtk */
-  gnome_init ("logview", NULL, argc, argv, 0, NULL);
+  gnome_init ("logview", VERSION, argc, argv);
   
   /*  Load graphics config */
   cfg = CreateConfig();
@@ -254,7 +254,7 @@ CreateMainWin ()
 
    app = gnome_app_new ("Logview", "System Log Viewer");
 
-   gtk_container_border_width ( GTK_CONTAINER (app), 3);
+   gtk_container_set_border_width ( GTK_CONTAINER (app), 3);
    gtk_signal_connect (GTK_OBJECT (app), "destroy",
 		       GTK_SIGNAL_FUNC (destroy), NULL);
    gtk_signal_connect (GTK_OBJECT (app), "delete_event",
@@ -277,7 +277,7 @@ CreateMainWin ()
    /* Create main canvas and scroll bar */
    frame = gtk_frame_new (NULL);
    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-   gtk_container_border_width (GTK_CONTAINER (frame), 2);
+   gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
    gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
    gtk_widget_set_style (frame, cfg->main_style);
    gtk_widget_show (frame);
@@ -330,7 +330,7 @@ CreateMainWin ()
 
    /* Create status area at bottom */
    hbox2 = gtk_hbox_new (FALSE, 2);
-   gtk_container_border_width ( GTK_CONTAINER (hbox2), 3);
+   gtk_container_set_border_width ( GTK_CONTAINER (hbox2), 3);
 
    label = (GtkLabel *)gtk_label_new ("Filename: ");
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
@@ -620,7 +620,7 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
 
    filesel = gtk_file_selection_new ("Open new logfile");
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), PATH_MESSAGES);
-   gtk_window_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
+   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
    gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
 		       "clicked", (GtkSignalFunc) FileSelectOk,
 		       filesel);
