@@ -77,7 +77,7 @@ ShowErrMessage (char *msg)
 
 printf("Error: [%s]\n", msg);
   msgbox = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_ERROR, "Ok", NULL);
-  gnome_dialog_set_modal (GNOME_DIALOG(msgbox)); 
+  gtk_window_set_modal (GTK_WINDOW(msgbox),TRUE); 
   gtk_widget_show (msgbox);
 }
 
