@@ -108,7 +108,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
      {
        /* monoptions = gtk_dialog_new ();   */
       monoptions = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-      gtk_container_border_width (GTK_CONTAINER (monoptions), 5);
+      gtk_container_set_border_width (GTK_CONTAINER (monoptions), 5);
       gtk_window_set_title (GTK_WINDOW (monoptions), "Monitor options");
       gtk_widget_set_style (monoptions, cfg->main_style);
       gtk_signal_connect (GTK_OBJECT (monoptions), "destroy",
@@ -119,7 +119,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
 			  NULL);
 
       vbox = (GtkBox *)gtk_vbox_new (FALSE, 2);
-      gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+      gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
       gtk_container_add (GTK_CONTAINER (monoptions), GTK_WIDGET (vbox));
       gtk_widget_show (GTK_WIDGET (vbox)); 
 
@@ -141,7 +141,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
       gtk_widget_set_usize (scrolled_win, 160, 100);
-      gtk_container_border_width (GTK_CONTAINER (scrolled_win), 3);
+      gtk_container_set_border_width (GTK_CONTAINER (scrolled_win), 3);
       gtk_box_pack_start (GTK_BOX (hbox), scrolled_win, TRUE, TRUE, 0);
       gtk_widget_set_style (scrolled_win, cfg->main_style);
       gtk_widget_show (scrolled_win);
@@ -160,7 +160,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
 	  gtk_widget_set_name (list_item, buffer);
 	  
 	  gtk_widget_set_style (list_item, cfg->main_style);
-	  gtk_container_border_width (GTK_CONTAINER (list_item), 0);
+	  gtk_container_set_border_width (GTK_CONTAINER (list_item), 0);
           gtk_widget_show (list_item);
         }
 
@@ -196,7 +196,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
       destlist = gtk_list_new ();
       gtk_list_set_selection_mode (GTK_LIST (srclist), GTK_SELECTION_SINGLE);
       gtk_container_add (GTK_CONTAINER (scrolled_win), destlist);
-      gtk_container_border_width (GTK_CONTAINER (scrolled_win), 3);
+      gtk_container_set_border_width (GTK_CONTAINER (scrolled_win), 3);
       gtk_widget_show (destlist);
 
       /* Make bottom part of window  -------------------------------- */
@@ -396,6 +396,7 @@ void
 go_monitor_log (GtkWidget * widget, gpointer client_data)
 {
    GtkWidget *label;
+   GtkWidget *swin;
    GtkWidget *notebook;
    GtkWidget *frame;
    GtkWidget *vbox;
@@ -450,7 +451,7 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
 
    /* monwindow = gtk_window_new (GTK_WINDOW_POPUP);  */ /*  Window without borders! */
    monwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-   gtk_container_border_width (GTK_CONTAINER (monwindow), 0);
+   gtk_container_set_border_width (GTK_CONTAINER (monwindow), 0);
    gtk_window_set_title (GTK_WINDOW (monwindow), "Monitoring logs..");
    gtk_widget_set_style (monwindow, cfg->main_style);
 
@@ -464,7 +465,7 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
 		       NULL);
    
    vbox = gtk_vbox_new (FALSE, 10);
-   gtk_container_border_width (GTK_CONTAINER (vbox), 0);
+   gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
    gtk_container_add( GTK_CONTAINER (monwindow), vbox);
    gtk_widget_show (vbox);
    
@@ -480,23 +481,25 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
        sprintf (logfile, "%s", loglist[i]->name );
        
        frame = gtk_frame_new (NULL);
-       gtk_container_border_width (GTK_CONTAINER (frame), 1);
+       gtk_container_set_border_width (GTK_CONTAINER (frame), 1);
        gtk_widget_set_usize (frame, 200, 150);
        gtk_widget_show (frame);
        
        /* Create destination list */
        clist = (GtkCList *)gtk_clist_new (1);
+       swin = gtk_scrolled_window_new (NULL, NULL);
+       gtk_container_add (GTK_CONTAINER (swin), GTK_WIDGET (clist));
        gtk_clist_set_column_width (clist, 0, 500);
        gtk_clist_set_selection_mode (clist, GTK_SELECTION_BROWSE);
-       gtk_clist_set_policy (clist,
-			     GTK_POLICY_AUTOMATIC,
-			     GTK_POLICY_AUTOMATIC);
+       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
+				       GTK_POLICY_AUTOMATIC,
+				       GTK_POLICY_AUTOMATIC);
 
        gtk_clist_set_column_justification (clist, 0, GTK_JUSTIFY_LEFT); 
        gtk_widget_set_style (GTK_WIDGET (clist), cfg->main_style);
        loglist[i]->mon_lines = (GtkCList *) clist;
-       gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (clist));
-       gtk_widget_show (GTK_WIDGET (clist));
+       gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (swin));
+       gtk_widget_show_all (swin);
        
        mon_read_last_page (loglist[i]);
        label = gtk_label_new (logfile);
@@ -519,7 +522,7 @@ mon_read_last_page (Log *log)
 {
   Page pg;
   char buffer[500];
-  gchar *texts[2];
+  const gchar *texts[2];
   int i, j;
 
   log->mon_numlines = 0;
@@ -561,7 +564,7 @@ mon_read_new_lines (Log *log)
 {
   Page pg;
   char buffer[500];
-  gchar *texts[2];
+  const gchar *texts[2];
   int i,j;
 
   fseek (log->fp, log->offset_end, SEEK_SET);
